#include <stdlib.h>

#include "xhw_types.h"
#include "xhw_memmap.h"
#include "xhw_tpm.h"
#include "xcore.h"
#include "xsysctl.h"
#include "xgpio.h"
#include "xwdt.h"
#include "xuart.h"

#include "segedlet.h"

void
board_init()
{
  WDTimerDisable();
  xSysCtlClockSet(CLOCK, xSYSCTL_OSC_MAIN | xSYSCTL_XTAL_8MHZ);
  SysCtlDelay(1000000);

  xSysCtlPeripheralEnable(xSYSCTL_PERIPH_GPIOD);
  xSysCtlPeripheralEnable(xSYSCTL_PERIPH_GPIOB);

  //Green LED
  xGPIOSPinTypeGPIOOutput(PB19);
  //Blue LED
  //xGPIOSPinTypeGPIOOutput(PD1);
  //Red LED
  xGPIOSPinTypeGPIOOutput(PB18);

  xGPIOPinWrite(xGPIO_PORTB_BASE, xGPIO_PIN_18, 1);
  xGPIOPinWrite(xGPIO_PORTB_BASE, xGPIO_PIN_19, 1);
  xGPIOPinWrite(xGPIO_PORTD_BASE, xGPIO_PIN_1, 1);
}

void
systick_init(float time)
{
  xSysTickPeriodSet(time / (1.0/ /*(48000000.0/16.0)*/ (float)CLOCK));
  xSysTickIntEnable();
  xSysTickValueGet();
  xSysTickEnable();

}

void
set_green(int v)
{
  xGPIOPinWrite(xGPIO_PORTB_BASE, xGPIO_PIN_19, v?0:1);
}

void
set_red(int v)
{
  xGPIOPinWrite(xGPIO_PORTB_BASE, xGPIO_PIN_18, v?0:1);
}

void
set_blue(int v)
{
  xGPIOSPinTypeGPIOOutput(PD1);
  xGPIOPinWrite(xGPIO_PORTD_BASE, xGPIO_PIN_1, v?0:1);
}

void
green_on()
{
  set_green(1);
}

void
green_off()
{
  set_green(0);
}

void
green_toggle()
{
  xGPIOSPinTypeGPIOOutput(PD1);
  set_green(xGPIOPinRead(xGPIO_PORTB_BASE, xGPIO_PIN_19));
}

void
red_on()
{
  set_red(1);
}

void
red_off()
{
  set_red(0);
}

void
red_toggle()
{
  set_red(xGPIOPinRead(xGPIO_PORTB_BASE, xGPIO_PIN_18));
}

void
blue_on()
{
  set_blue(1);
}

void
blue_off()
{
  set_blue(0);
}

void
blue_toggle()
{
  set_blue(xGPIOPinRead(xGPIO_PORTD_BASE, xGPIO_PIN_1));
}

int
blue_pwm(float fr, int duty)
{
  int d= 0;
  int divby= 1;
  int ifr= CLOCK/4;
  int tfr;
  int steps;
  int compare_level;
  //volatile int sc;

  SysCtlPeripheralClockSourceSet(SYSCTL_PERIPH_TPM_S_MCGPLLCLK_2);
 // xHWREG(0x40048004)= 0x05010000;
  xSysCtlPeripheralEnable(xSYSCTL_PERIPH_PWMA);
  xSPinTypePWM(TIM0CH1, PD1);
  // disable timer
  xHWREG(PWMA_BASE+TPM_SC)= TPM_SC_CMOD_DIS;
  while ((divby= (1<<d)) < 129)
    {
      float tstep;
      tfr= ifr/divby;
      tstep= 1/(float)tfr;
      steps= (1/fr)/tstep;
      if (steps < 0xffff)
        break;
      d++;
    }
  if (steps > 0xffff)
    return steps;
  compare_level= (steps * duty)/100;

  // select prescaler, and edge-aligned mode
  xHWREG(PWMA_BASE+TPM_SC)= d;
  // tfr: timer stepping freq, steps= nr of steps needed for fr output
  xHWREG(PWMA_BASE+TPM_MOD)= steps;

    // use channel 1, high-true pulses
  xHWREG(PWMA_BASE+TPM_C1SC)= TPM_CNSC_MSB | TPM_CNSC_ELSA;
  /*sc=*/ xHWREG(PWMA_BASE+TPM_C1SC);

  // calc and set compare level
  xHWREG(PWMA_BASE+TPM_C1V)= compare_level;

  // start
  xHWREG(PWMA_BASE+TPM_SC)= xHWREG(PWMA_BASE+TPM_SC)|TPM_SC_CMOD_CLK;
  /*sc=*/ xHWREG(PWMA_BASE+TPM_SC);
  return steps;
}

void
uart_init()
{
  //
  // Enable GPIO and UART Clock
  //
  SysCtlPeripheralEnable(SYSCTL_PERIPH_UART0);
  SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOA);

  //
  // Remap UART pin to GPIO Port UART0_RX --> PA2 UART0_TX --> PA1
  //
  xSPinTypeUART(UART0RX, PA1);
  xSPinTypeUART(UART0TX, PA2);

  //
  // Set UART clock
  //
  SysCtlPeripheralClockSourceSet(SYSCTL_PERIPH_UART0_S_MCGPLLCLK_2);

  //
  // Disable UART Receive/Transmit
  //
  UARTDisable(UART0_BASE, UART_TX | UART_RX);

  //
  // Configure UART Baud 115200
  //
  UARTConfigSet(UART0_BASE, 19200, UART_CONFIG_SAMPLE_RATE_15 | UART_CONFIG_WLEN_8 | UART_CONFIG_PAR_NONE | UART_CONFIG_STOP_1);

  //
  // Enable UART Receive and Transmit
  //
  UARTEnable(UART0_BASE, UART_TX | UART_RX);
}

int
uart_avail()
{
  return UARTCharsAvail(UART0_BASE);
}

int uart_echo= 1;

int
uart_read(char *ptr, int len)
{
  int i;

  for(i = 0; i < len; i++)
    {
      if (!uart_avail())
        return i;
      *ptr++ = UARTCharGet(UART0_BASE);
    }

  return len;
}

int
uart_write(char *ptr, int len)
{
  int i;

  for (i= 0; i<len; i++)
    UARTCharPut(UART0_BASE, *ptr++);

  return len;
}


#define TSI0_GENCS (TSI_BASE+0)
#define TSI0_DATA (TSI_BASE+4)

#define REG(x) (*((volatile uint32_t *)(x)))
#define GENCS (REG(TSI0_GENCS))
#define DATA (REG(TSI0_DATA))

int tsi_value;
int tsi_base;
int tsi_raw;
int tsi_prev_on, tsi_prev_off;

enum {
	tsi_flt_time= 5
};
int tsi_flt_cnt= tsi_flt_time;
int tsi_flt_values[2]= { 0, 0 };
int tsi_flt_idx= 0;
int tsi_flt_val= 0;

void
TSIIntHandler(void)
{
  tsi_value= DATA & 0xffff;
  tsi_start();
}

void
tsi_init()
{
  uint32_t r;

  // ENABLE TPM1
  r= xHWREG(/*SCGC6*/0x4004803c);
  r|= 1<<25;
  xHWREG(0x4004803c)= r;

  // Enable TSI
  r= xHWREG(/*SCGC5*/0x40048038);
  r|= /*SIM_SCGC5_TSI_MASK*/1<<5;
  xHWREG(0x40048038)= r;

  r= xHWREG(/*PORTB_PCR16*/0x4004A040);
  r&= ~(0b111 << 8);
  r|= 0b000 << 8;
  xHWREG(0x4004A040)= r;
  r= xHWREG(/*PORTB_PCR17*/0x4004A044);
  r&= ~(0b111 << 8);
  r|= 0b000 << 8;
  xHWREG(0x4004A044)= r;

  r= 0;
  // ESOR: end-of-scan
  r|= 1 << 28;
  // MODE: capacitive sense
  r|= 0b0000 << 24;
  // REFCHREG: 8uA
  r|= 0b100 << 21;
  // DVOLT: 0
  r|= 0b00 << 19;
  // EXTCHRG: 64uA
  r|= 0b111 << 16;
  // PS: div by 1
  r|= 0b000 << 13;
  // NSNC: 30
  r|= 0b11101 << 8;
  // TSIEN: disable (yet)
  r|= 0 << 7;
  // TSIIEN: disable
  r|= 0 << 6;
  // STPE: disbale
  r|= 0 << 5;
  // STM: software trigger
  r|= 0 << 4;
  // CURSW: not swapped
  r|= 0 << 1;

  GENCS= r;

  r= 0;
  // TSICH: channel9
  r|= 0b1001 << 28;
  // DMAEN: disabled
  r|= 0 << 23;
  // SWTS: no effect
  r|= 0 << 22;
  // TSICNT: 0
  r|= 0 << 0;
  DATA= r;

  r= GENCS;
  r|= (1 << 7);
  GENCS= r;

  tsi_scan();
  tsi_base= tsi_raw;
  tsi_value= 0;
  tsi_prev_on= tsi_prev_off= tsi_touch();
}

void
tsi_start()
{
  uint32_t r;

  r= GENCS;
  r|= (1 << 2);
  GENCS= r;

  r= DATA;
  r|= 1 << 22;
  r&= ~0xffff;
  DATA= r;
}

int
tsi_progress()
{
  return (GENCS & (1<<3))?1:0;
}

int
tsi_done()
{
  return (GENCS & (1<<2))?1:0;
}

int
tsi_get()
{
  uint32_t r;

  r= GENCS;
  r|= (1 << 2);
  GENCS= r;

  tsi_raw= DATA & 0xffff;
  if (tsi_raw < tsi_base)
    tsi_value= 0;
  else
    tsi_value= tsi_raw-tsi_base;

  if (--tsi_flt_cnt == 0)
  {
	  int d;
	  tsi_flt_cnt= tsi_flt_time;
	  tsi_flt_values[tsi_flt_idx++]= tsi_value;
	  tsi_flt_idx%= 2;

	  d= tsi_flt_values[0] - tsi_flt_values[1];
	  if (abs(d) < 2)
	  {
		  tsi_flt_val= tsi_flt_values[0];
	  }
  }

  return tsi_value;
}

int
tsi_scan()
{
  if (tsi_progress())
    while (!tsi_done())
      ;
  tsi_start();
  while (!tsi_done())
    ;
  return tsi_get();
}


int
tsi_touch()
{
	if (tsi_flt_val > 5)
		return 1;
	else
		return 0;
  return (tsi_raw > tsi_base+5)?1:0;
}

int
tsi_touched()
{
  if (tsi_prev_on != tsi_touch())
    {
      tsi_prev_on= tsi_touch();
      return tsi_prev_on;
    }
  return 0;
}

int
tsi_released()
{
  if (tsi_prev_off != tsi_touch())
    {
      tsi_prev_off= tsi_touch();
      return tsi_prev_off?0:1;
    }
  return 0;
}
